@@ -1,6 +1,6 @@
 package Treex::Core::Document;
 {
-  $Treex::Core::Document::VERSION = '0.08302_1';
+  $Treex::Core::Document::VERSION = '0.08330_1';
 }
 
 use Moose;
@@ -135,7 +135,7 @@ sub BUILD {
                 $pmldoc = eval {
                     $factory->createDocumentFromFile( $params_rf->{filename} );
                 };
-                log_fatal "Error while loading " . $params_rf->{filename}
+                log_fatal "Error while loading " . $params_rf->{filename} . ($@ ? "\n$@" : '')
                     if !defined $pmldoc;
             }
         }
@@ -532,11 +532,13 @@ sub retrieve_storable {
     while (<$FILEHANDLE>) {
         $serialized .= $_;
     }
-    #    my $retrieved_doc = Storable::retrieve_fd(*$FILEHANDLE) or log_fatal($!);
+    # my $retrieved_doc = Storable::retrieve_fd(*$FILEHANDLE) or log_fatal($!);
     my $retrieved_doc = Storable::thaw( $serialized ) or log_fatal $!;
 
     if ( not ref($file) ) {
         $retrieved_doc->set_loaded_from($file);
+        my ( $volume, $dirs, $file ) = File::Spec->splitpath($file);
+        $retrieved_doc->set_path($volume . $dirs);
         # $retrieved_doc->changeFilename($file); # why this doesn't affect the name displayed in TrEd?
     }
 
@@ -561,7 +563,7 @@ Treex::Core::Document - representation of a text and its linguistic analyses in
 
 =head1 VERSION
 
-version 0.08302_1
+version 0.08330_1
 
 =head1 DESCRIPTION
 
