@@ -1,9 +1,9 @@
 package Treex::Core::Files;
 {
-  $Treex::Core::Files::VERSION = '0.08302_1';
+  $Treex::Core::Files::VERSION = '0.08330_1';
 }
 use Moose;
-use MooseX::SemiAffordanceAccessor;
+use MooseX::SemiAffordanceAccessor 0.09;
 use Treex::Core::Log;
 use autodie;
 use File::Slurp 9999.19;
@@ -83,7 +83,7 @@ Treex::Core::Files - helper class for iterating over filenames
 
 =head1 VERSION
 
-version 0.08302_1
+version 0.08330_1
 
 =head1 SYNOPSIS
 
